import { defineComponent, computed, createElementBlock, openBlock, createElementVNode, normalizeClass, unref, createCommentVNode, withModifiers, Fragment, renderList, toDisplayString } from "vue";
import useClasses from "../../composables/useClasses/index.js";
const _hoisted_1 = { "aria-label": "Page navigation" }, _hoisted_2 = ["onClick"], _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "Pagination",
  props: {
    /**
     * Current page number
     */
    modelValue: {
      type: Number,
      required: !0
    },
    /**
     * Total number of pages
     */
    totalPages: {
      type: Number,
      required: !0
    },
    /**
     * Number of page links to show
     */
    limit: {
      type: Number,
      default: 5
    },
    /**
     * Show first/last page links
     */
    showFirstLast: {
      type: Boolean,
      default: !0
    },
    /**
     * Size of the pagination component
     */
    size: {
      type: String,
      default: "",
      validator: (value) => ["", "sm", "lg"].includes(value)
    },
    /**
     * Alignment of the pagination component
     */
    align: {
      type: String,
      default: "",
      validator: (value) => ["", "center", "end"].includes(value)
    }
  },
  emits: ["update:modelValue"],
  setup(__props, { emit: __emit }) {
    const props = __props, emit = __emit, currentPage = computed(() => props.modelValue), showFirst = computed(() => props.showFirstLast), showLast = computed(() => props.showFirstLast), displayedPages = computed(() => {
      const pages = [], halfLimit = Math.floor(props.limit / 2);
      let start = Math.max(1, currentPage.value - halfLimit), end = Math.min(props.totalPages, start + props.limit - 1);
      end === props.totalPages && (start = Math.max(1, end - props.limit + 1));
      for (let i = start; i <= end; i++)
        pages.push(i);
      return pages;
    }), onPageClick = (page) => {
      page >= 1 && page <= props.totalPages && page !== currentPage.value && emit("update:modelValue", page);
    }, { classes } = useClasses(computed(() => [
      props.size ? `pagination-${props.size}` : void 0,
      props.align ? `justify-content-${props.align}` : void 0
    ]));
    return (_ctx, _cache) => (openBlock(), createElementBlock("nav", _hoisted_1, [
      createElementVNode("ul", {
        class: normalizeClass(["pagination", unref(classes)])
      }, [
        showFirst.value ? (openBlock(), createElementBlock("li", {
          key: 0,
          class: normalizeClass(["page-item", { disabled: currentPage.value === 1 }])
        }, [
          createElementVNode("a", {
            class: "page-link",
            href: "#",
            onClick: _cache[0] || (_cache[0] = withModifiers(($event) => onPageClick(1), ["prevent"])),
            "aria-label": "First"
          }, _cache[4] || (_cache[4] = [
            createElementVNode("span", { "aria-hidden": "true" }, "««", -1)
          ]))
        ], 2)) : createCommentVNode("", !0),
        createElementVNode("li", {
          class: normalizeClass(["page-item", { disabled: currentPage.value === 1 }])
        }, [
          createElementVNode("a", {
            class: "page-link",
            href: "#",
            onClick: _cache[1] || (_cache[1] = withModifiers(($event) => onPageClick(currentPage.value - 1), ["prevent"])),
            "aria-label": "Previous"
          }, _cache[5] || (_cache[5] = [
            createElementVNode("span", { "aria-hidden": "true" }, "«", -1)
          ]))
        ], 2),
        (openBlock(!0), createElementBlock(Fragment, null, renderList(displayedPages.value, (page) => (openBlock(), createElementBlock("li", {
          key: page,
          class: normalizeClass(["page-item", { active: page === currentPage.value }])
        }, [
          createElementVNode("a", {
            class: "page-link",
            href: "#",
            onClick: withModifiers(($event) => onPageClick(page), ["prevent"])
          }, toDisplayString(page), 9, _hoisted_2)
        ], 2))), 128)),
        createElementVNode("li", {
          class: normalizeClass(["page-item", { disabled: currentPage.value === __props.totalPages }])
        }, [
          createElementVNode("a", {
            class: "page-link",
            href: "#",
            onClick: _cache[2] || (_cache[2] = withModifiers(($event) => onPageClick(currentPage.value + 1), ["prevent"])),
            "aria-label": "Next"
          }, _cache[6] || (_cache[6] = [
            createElementVNode("span", { "aria-hidden": "true" }, "»", -1)
          ]))
        ], 2),
        showLast.value ? (openBlock(), createElementBlock("li", {
          key: 1,
          class: normalizeClass(["page-item", { disabled: currentPage.value === __props.totalPages }])
        }, [
          createElementVNode("a", {
            class: "page-link",
            href: "#",
            onClick: _cache[3] || (_cache[3] = withModifiers(($event) => onPageClick(__props.totalPages), ["prevent"])),
            "aria-label": "Last"
          }, _cache[7] || (_cache[7] = [
            createElementVNode("span", { "aria-hidden": "true" }, "»»", -1)
          ]))
        ], 2)) : createCommentVNode("", !0)
      ], 2)
    ]));
  }
});
export {
  _sfc_main as default
};
//# sourceMappingURL=Pagination.vue.js.map
